==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/CalendarDateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CalendarDateDescription } from "./CalendarDateDescription";
/**
 * @hidden
 */
var CalendarDateDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(CalendarDateDescriptionMetadata, _super);
    function CalendarDateDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CalendarDateDescriptionMetadata.b = function (a) {
        if (CalendarDateDescriptionMetadata.a == null) {
            CalendarDateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CalendarDateDescriptionMetadata.c(CalendarDateDescriptionMetadata.a);
        }
        if (a.k(CalendarDateDescriptionMetadata.a)) {
            return;
        }
        a.aa(CalendarDateDescriptionMetadata.a);
    };
    CalendarDateDescriptionMetadata.c = function (a) {
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Date", "Date");
        a.item("IsCurrentMonth", "Boolean");
        a.item("IsPrevMonth", "Boolean");
        a.item("IsNextMonth", "Boolean");
    };
    CalendarDateDescriptionMetadata.d = function (a) {
        CalendarDateDescriptionMetadata.b(a);
        a.ac("CalendarDate", function () { return new CalendarDateDescription(); });
        a.ab("CalendarDate", CalendarDateDescriptionMetadata.a);
    };
    CalendarDateDescriptionMetadata.$t = markType(CalendarDateDescriptionMetadata, 'CalendarDateDescriptionMetadata');
    CalendarDateDescriptionMetadata.a = null;
    return CalendarDateDescriptionMetadata;
}(Base));
export { CalendarDateDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/CalendarDateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CalendarDateDescription } from "./CalendarDateDescription";
/**
 * @hidden
 */
var CalendarDateDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CalendarDateDescriptionMetadata, _super);
    function CalendarDateDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CalendarDateDescriptionMetadata.b = function (a) {
        if (CalendarDateDescriptionMetadata.a == null) {
            CalendarDateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CalendarDateDescriptionMetadata.c(CalendarDateDescriptionMetadata.a);
        }
        if (a.k(CalendarDateDescriptionMetadata.a)) {
            return;
        }
        a.ac(CalendarDateDescriptionMetadata.a);
    };
    CalendarDateDescriptionMetadata.c = function (a) {
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__marshalByValue", "Boolean");
        a.item("Date", "Date");
        a.item("IsCurrentMonth", "Boolean");
        a.item("IsPrevMonth", "Boolean");
        a.item("IsNextMonth", "Boolean");
    };
    CalendarDateDescriptionMetadata.d = function (a) {
        CalendarDateDescriptionMetadata.b(a);
        a.ae("CalendarDate", function () { return new CalendarDateDescription(); });
        a.ad("CalendarDate", CalendarDateDescriptionMetadata.a);
    };
    CalendarDateDescriptionMetadata.$t = markType(CalendarDateDescriptionMetadata, 'CalendarDateDescriptionMetadata');
    CalendarDateDescriptionMetadata.a = null;
    return CalendarDateDescriptionMetadata;
}(Base));
export { CalendarDateDescriptionMetadata };
